pub struct Intents(/* private fields */);Expand description
Gateway intents.
Developers must specify intents when connecting to the gateway. The
intents specified correspond with the events received. To specify
multiple intents, create a union using the | operator. See
Discord Docs/Gateway Intents.
Implementations
Sourceimpl Intents
impl Intents
Sourcepub const GUILDS: Self
pub const GUILDS: Self
Guilds intent.
Event(s) received:
GUILD_CREATEGUILD_UPDATEGUILD_DELETEGUILD_ROLE_CREATEGUILD_ROLE_UPDATEGUILD_ROLE_DELETECHANNEL_CREATECHANNEL_UPDATECHANNEL_DELETECHANNEL_PINS_UPDATETHREAD_CREATETHREAD_UPDATETHREAD_DELETETHREAD_LIST_SYNCTHREAD_MEMBER_UPDATETHREAD_MEMBERS_UPDATESTAGE_INSTANCE_CREATESTAGE_INSTANCE_UPDATESTAGE_INSTANCE_DELETE
Sourcepub const GUILD_MEMBERS: Self
pub const GUILD_MEMBERS: Self
Guild members intent.
This intent is privileged. See Discord Docs/Privileged Intents.
Event(s) received:
Sourcepub const GUILD_MODERATION: Self
pub const GUILD_MODERATION: Self
Guild moderation intent.
Event(s) received:
Sourcepub const GUILD_EMOJIS_AND_STICKERS: Self
pub const GUILD_EMOJIS_AND_STICKERS: Self
Sourcepub const GUILD_INTEGRATIONS: Self
pub const GUILD_INTEGRATIONS: Self
Guild integrations intent.
Event(s) received:
Sourcepub const GUILD_WEBHOOKS: Self
pub const GUILD_WEBHOOKS: Self
Sourcepub const GUILD_INVITES: Self
pub const GUILD_INVITES: Self
Sourcepub const GUILD_VOICE_STATES: Self
pub const GUILD_VOICE_STATES: Self
Sourcepub const GUILD_PRESENCES: Self
pub const GUILD_PRESENCES: Self
Guild presences intent.
This intent is privileged. See Discord Docs/Privileged Intents.
Event(s) received:
Sourcepub const GUILD_MESSAGES: Self
pub const GUILD_MESSAGES: Self
Guild messages intent.
Event(s) received:
Sourcepub const GUILD_MESSAGE_REACTIONS: Self
pub const GUILD_MESSAGE_REACTIONS: Self
Guild message reactions intent.
Event(s) received:
Sourcepub const GUILD_MESSAGE_TYPING: Self
pub const GUILD_MESSAGE_TYPING: Self
Sourcepub const DIRECT_MESSAGES: Self
pub const DIRECT_MESSAGES: Self
Direct messages intent.
Event(s) received:
This is different from the GUILD_MESSAGES intent in that the bot
will receive message events from locations other than guilds.
Sourcepub const DIRECT_MESSAGE_REACTIONS: Self
pub const DIRECT_MESSAGE_REACTIONS: Self
Direct message reactions intent.
Event(s) received:
MESSAGE_REACTION_ADDMESSAGE_REACTION_REMOVEMESSAGE_REACTION_REMOVE_ALLMESSAGE_REACTION_REMOVE_EMOJI
This is different from the GUILD_MESSAGE_REACTIONS event in that
the bot will receive message reaction events from locations other
than guilds.
Sourcepub const DIRECT_MESSAGE_TYPING: Self
pub const DIRECT_MESSAGE_TYPING: Self
Direct message typing intent.
Event(s) received:
This is different from the GUILD_MESSAGE_TYPING intent in that
the bot will receive typing start events from locations other than
guilds.
Sourcepub const MESSAGE_CONTENT: Self
pub const MESSAGE_CONTENT: Self
Message content intent.
This intent is privileged. See Discord Docs/Privileged Intents.
This intent allows you to receive the contents of all messages.
Sourcepub const GUILD_SCHEDULED_EVENTS: Self
pub const GUILD_SCHEDULED_EVENTS: Self
Guild scheduled events intent.
Event(s) received:
Sourcepub const AUTO_MODERATION_CONFIGURATION: Self
pub const AUTO_MODERATION_CONFIGURATION: Self
Auto moderation configuration intent.
Event(s) received:
Sourcepub const AUTO_MODERATION_EXECUTION: Self
pub const AUTO_MODERATION_EXECUTION: Self
Sourcepub const GUILD_MESSAGE_POLLS: Self
pub const GUILD_MESSAGE_POLLS: Self
Sourcepub const DIRECT_MESSAGE_POLLS: Self
pub const DIRECT_MESSAGE_POLLS: Self
Sourceimpl Intents
impl Intents
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Intents
impl Intents
Sourcepub const fn iter(&self) -> Iter<Intents>
pub const fn iter(&self) -> Iter<Intents>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Intents>
pub const fn iter_names(&self) -> IterNames<Intents>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.